<?php

namespace Drupal\virtual_base;

use Drupal\Core\Cache\CacheableMetadata;
use Symfony\Component\HttpFoundation\Request;

/**
 * Interface for Service VirtualBaseManager.
 */
interface VirtualBaseManagerInterface {

  /**
   * Get the config (with caching).
   */
  public function getConfig();

  /**
   * Get the path prefix or null if not enabled or not set.
   *
   * The current request can be checked if it contains the path prefix.
   *
   * @param \Symfony\Component\HttpFoundation\Request|null $request
   *   Gives the request if available.
   * @param bool $checkRequest
   *   If true, the request object will be checked for the path prefix.
   *
   * @return string|null
   *   Returns the path prefix or null if not enabled or not set.
   */
  public function getPathPrefix(Request $request = NULL, bool $checkRequest = TRUE) : ?string;

  /**
   * Resolves inbound path.
   *
   * @param string $path
   *   The path to process.
   * @param \Symfony\Component\HttpFoundation\Request|null $request
   *   The HttpRequest object representing the request to process. Note, if this
   *   method is being called via the path_processor_manager service and is not
   *   part of routing, the current request object must be cloned before being
   *   passed in.
   *
   * @return string
   *   The processed path.
   */
  public function resolveInboundPath($path, $request = NULL) : string;

  /**
   * Resolves Outbound path.
   *
   * @param string $path
   *   The path to process.
   * @param \Symfony\Component\HttpFoundation\Request|null $request
   *   The HttpRequest object representing the request to process. Note, if this
   *   method is being called via the path_processor_manager service and is not
   *   part of routing, the current request object must be cloned before being
   *   passed in.
   * @param \Drupal\Core\Render\BubbleableMetadata $bubbleableMetadata
   *   (optional) Object to collect path processors' bubbleable metadata.
   *
   * @return string
   *   The processed path.
   */
  public function resolveOutboundPath($path, $request = NULL, CacheableMetadata $bubbleableMetadata = NULL) : string;

  /**
   * Alter HTML content to add the path prefix.
   *
   * @param string $path_prefix
   *   The path prefix to use.
   * @param string $text
   *   The text to alter.
   *
   * @return string|null
   *   Returns the patched text or null if nothing was changed.
   */
  public function alterHtml(string $path_prefix, string $text) : ?string;

}
